@@ -3,7 +3,7 @@ test_that("Test table creation of t_ds_slide", {
 })
 
 test_that("Test table creation of t_ds_slide", {
-  expect_snapshot(t_ds_slide(adsl = testdata$adsl, side_by_side = TRUE))
+  expect_snapshot(t_ds_slide(adsl = testdata$adsl, side_by_side = "GlobalChina"))
 })
 
 test_that("Test table creation of t_ds_slide", {
@@ -11,6 +11,6 @@ test_that("Test table creation of t_ds_slide", {
 })
 
 test_that("Test table creation of t_ds_slide", {
-  expect_snapshot(t_ds_slide(adsl = testdata$adsl, split_by_study = TRUE, side_by_side = TRUE))
-  expect_warning(t_ds_slide(adsl = testdata$adsl, split_by_study = TRUE, side_by_side = TRUE))
+  expect_snapshot(t_ds_slide(adsl = testdata$adsl, split_by_study = TRUE, side_by_side = "GlobalChina"))
+  expect_warning(t_ds_slide(adsl = testdata$adsl, split_by_study = TRUE, side_by_side = "GlobalChina"))
 })
